@@ -240,8 +240,8 @@ getSnowflakeAuthToken <- function(url, snowflakeConnectionName) {
   parsedURL <- parseHttpUrl(url)
   ingressURL <- parsedURL$host
 
-  token <- snowflake_credentials(
-    snowflake_connection(snowflakeConnectionName),
+  token <- snowflakeauth::snowflake_credentials(
+    snowflakeauth::snowflake_connection(snowflakeConnectionName),
     spcs_endpoint = ingressURL
   )
 
