@@ -1,4 +1,3 @@
-
 # quarto ------------------------------------------------------------------
 
 fakeQuartoMetadata <- function(version, engines) {
@@ -9,7 +8,8 @@ fakeQuartoMetadata <- function(version, engines) {
   return(metadata)
 }
 
-test_that("inferQuartoInfo correctly detects info when quarto is provided alone", {
+test_that("inferQuartoInfo correctly detects document info when quarto is provided alone", {
+  skip_on_cran()
   skip_if_no_quarto()
 
   quartoInfo <- inferQuartoInfo(
@@ -19,9 +19,15 @@ test_that("inferQuartoInfo correctly detects info when quarto is provided alone"
   )
   expect_named(quartoInfo, c("version", "engines"))
   expect_equal(quartoInfo$engines, I(c("markdown")))
+})
 
+test_that("inferQuartoInfo correctly detects website info when quarto is provided alone", {
+  skip_on_cran()
+  skip_if_no_quarto()
+
+  appDir <- local_temp_app(quarto_website_r_files)
   quartoInfo <- inferQuartoInfo(
-    appDir = test_path("quarto-website-r"),
+    appDir = appDir,
     appPrimaryDoc = NULL,
     metadata = list()
   )
@@ -30,17 +36,24 @@ test_that("inferQuartoInfo correctly detects info when quarto is provided alone"
 })
 
 test_that("inferQuartoInfo prefers metadata over quarto inspect", {
-  metadata <- fakeQuartoMetadata(version = "99.9.9", engines = c("internal-combustion"))
+  metadata <- fakeQuartoMetadata(
+    version = "99.9.9",
+    engines = c("internal-combustion")
+  )
 
+  appDir <- local_temp_app(quarto_website_r_files)
   quartoInfo <- inferQuartoInfo(
-    appDir = test_path("quarto-website-r"),
+    appDir = appDir,
     appPrimaryDoc = NULL,
     metadata = metadata
   )
-  expect_equal(quartoInfo, list(
-    version = "99.9.9",
-    engines = I("internal-combustion")
-  ))
+  expect_equal(
+    quartoInfo,
+    list(
+      version = "99.9.9",
+      engines = I("internal-combustion")
+    )
+  )
 })
 
 test_that("quartoInspect requires quarto", {
@@ -50,17 +63,25 @@ test_that("quartoInspect requires quarto", {
   })
 })
 
-test_that("quartoInspect identifies Quarto projects", {
+test_that("quartoInspect identifies Quarto projects (website)", {
+  skip_on_cran()
   skip_if_no_quarto()
 
-  inspect <- quartoInspect(test_path("quarto-website-r"))
+  appDir <- local_temp_app(quarto_website_r_files)
+  inspect <- quartoInspect(appDir)
   expect_true(all(c("quarto", "engines") %in% names(inspect)))
+})
+
+test_that("quartoInspect identifies Quarto projects (shiny)", {
+  skip_on_cran()
+  skip_if_no_quarto()
 
   inspect <- quartoInspect(test_path("quarto-proj-r-shiny"))
   expect_true(all(c("quarto", "engines") %in% names(inspect)))
 })
 
 test_that("quartoInspect identifies Quarto documents", {
+  skip_on_cran()
   skip_if_no_quarto()
 
   inspect <- quartoInspect(
@@ -71,30 +92,37 @@ test_that("quartoInspect identifies Quarto documents", {
 })
 
 test_that("quartoInspect processes content within paths containing spaces", {
+  skip_on_cran()
   skip_if_no_quarto()
 
   parent <- withr::local_tempdir()
   dir <- file.path(parent, "space dir")
   dir.create(dir)
-  writeLines(c(
-    "---",
-    "title: space path",
-    "---",
-    "this is a document within a path having spaces."
-  ), file.path(dir, "index.qmd"))
+  writeLines(
+    c(
+      "---",
+      "title: space path",
+      "---",
+      "this is a document within a path having spaces."
+    ),
+    file.path(dir, "index.qmd")
+  )
   inspect <- quartoInspect(dir, "index.qmd")
   expect_equal(inspect$engines, c("markdown"))
 })
 
 test_that("quartoInspect processes content with filenames containing spaces", {
+  skip_on_cran()
   skip_if_no_quarto()
 
-  dir <- local_temp_app(list("space file.qmd" = c(
-    "---",
-    "title: space name",
-    "---",
-    "this is a document with a filename having spaces."
-  )))
+  dir <- local_temp_app(list(
+    "space file.qmd" = c(
+      "---",
+      "title: space name",
+      "---",
+      "this is a document with a filename having spaces."
+    )
+  ))
   inspect <- quartoInspect(dir, "space file.qmd")
   expect_equal(inspect$engines, c("markdown"))
 })
@@ -112,17 +140,20 @@ strip_quarto_trace <- function(lines) {
 }
 
 test_that("quartoInspect produces an error when a document cannot be inspected", {
+  skip_on_cran()
   skip_if_no_quarto()
 
   # Suppress colors from Quarto errors.
   withr::local_envvar(NO_COLOR = "1")
 
-  dir <- local_temp_app(list("bad.qmd" = c(
-    "---",
-    "format: unsupported",
-    "---",
-    "this is a document using an unsupported format."
-  )))
+  dir <- local_temp_app(list(
+    "bad.qmd" = c(
+      "---",
+      "format: unsupported",
+      "---",
+      "this is a document using an unsupported format."
+    )
+  ))
   expect_snapshot(
     quartoInspect(dir, "bad.qmd"),
     error = TRUE,
@@ -131,6 +162,7 @@ test_that("quartoInspect produces an error when a document cannot be inspected",
 })
 
 test_that("quartoInspect produces an error when a project cannot be inspected", {
+  skip_on_cran()
   skip_if_no_quarto()
 
   # Suppress colors from Quarto errors.
