@@ -45,6 +45,8 @@ test_that("extra packages are snapshotted", {
 test_that("works with BioC packages", {
   skip_on_cran()
   skip_on_ci()
+  skip_if_not_installed("BiocManager")
+  skip_if_not_installed("Biobase")
 
   app <- local_temp_app(list(
     "index.R" = c(
