@@ -1,29 +1,9 @@
-context("cookies")
-
-test_that("URL parsing works", {
-  p <- parseHttpUrl("http://yahoo.com")
-  expect_equal(p$protocol, "http")
-  expect_equal(p$host, "yahoo.com")
-  expect_equal(p$port, "")
-  expect_equal(p$path, "") #TODO: bug? Should default to /?
-
-  p <- parseHttpUrl("https://rstudio.com/about")
-  expect_equal(p$protocol, "https")
-  expect_equal(p$host, "rstudio.com")
-  expect_equal(p$port, "")
-  expect_equal(p$path, "/about")
-
-  p <- parseHttpUrl("http://127.0.0.1:3939/stuff/here/?who-knows")
-  expect_equal(p$protocol, "http")
-  expect_equal(p$host, "127.0.0.1")
-  expect_equal(p$port, "3939")
-  expect_equal(p$path, "/stuff/here/?who-knows") #TODO: bug?
-})
-
 test_that("Parsing cookies works", {
-  parsedUrl <- parseHttpUrl("http://rstudio.com/test/stuff")
   # Note that the Expires field is ignored
-  cookie <- parseCookie(parsedUrl, "mycookie=myvalue; Path=/; Expires=Sat, 24 Jun 2017 16:16:05 GMT; Max-Age=3600; HttpOnly")
+  cookie <- parseCookie(
+    "mycookie=myvalue; Path=/; Expires=Sat, 24 Jun 2017 16:16:05 GMT; Max-Age=3600; HttpOnly",
+    "/"
+  )
   expect_equal(cookie$name, "mycookie")
   expect_equal(cookie$value, "myvalue")
   expect_true(cookie$expires > Sys.time() + 3595)
@@ -32,7 +12,7 @@ test_that("Parsing cookies works", {
   expect_false(cookie$secure)
 
   # Max-Age with no semicolon, non-root path
-  cookie <- parseCookie(parsedUrl, "mycookie2=myvalue2; Secure; Path=/test; max-AGE=3600")
+  cookie <- parseCookie("mycookie2=myvalue2; Secure; Path=/test; max-AGE=3600")
   expect_equal(cookie$name, "mycookie2")
   expect_equal(cookie$value, "myvalue2")
   expect_true(cookie$expires > Sys.time() + 3595)
@@ -41,7 +21,7 @@ test_that("Parsing cookies works", {
   expect_true(cookie$secure)
 
   # Path with no semicolon, no max age
-  cookie <- parseCookie(parsedUrl, "mycookie2=myvalue2; PATH=/test")
+  cookie <- parseCookie("mycookie2=myvalue2; PATH=/test")
   expect_equal(cookie$name, "mycookie2")
   expect_equal(cookie$value, "myvalue2")
   expect_true(cookie$expires > (Sys.time() + 10^9))
@@ -49,7 +29,7 @@ test_that("Parsing cookies works", {
   expect_false(cookie$secure)
 
   # No path, value with no semicolon
-  cookie <- parseCookie(parsedUrl, "mycookie2=myvalue2")
+  cookie <- parseCookie("mycookie2=myvalue2")
   expect_equal(cookie$name, "mycookie2")
   expect_equal(cookie$value, "myvalue2")
   expect_true(cookie$expires > (Sys.time() + 10^9))
@@ -57,7 +37,7 @@ test_that("Parsing cookies works", {
   expect_false(cookie$secure)
 
   # Trailing secure
-  cookie <- parseCookie(parsedUrl, "mycookie2=myvalue2; Secure")
+  cookie <- parseCookie("mycookie2=myvalue2; Secure")
   expect_equal(cookie$name, "mycookie2")
   expect_equal(cookie$value, "myvalue2")
   expect_true(cookie$expires > (Sys.time() + 10^9))
@@ -65,7 +45,9 @@ test_that("Parsing cookies works", {
   expect_true(cookie$secure)
 
   # Full cookie with spaces around =s
-  cookie <- parseCookie(parsedUrl, "mycookie = myvalue; SEcure; Path = /; Expires = Sat, 24 Jun 2017 16:16:05 GMT; Max-Age = 3600; HttpOnly")
+  cookie <- parseCookie(
+    "mycookie = myvalue; SEcure; Path = /; Expires = Sat, 24 Jun 2017 16:16:05 GMT; Max-Age = 3600; HttpOnly"
+  )
   expect_equal(cookie$name, "mycookie")
   expect_equal(cookie$value, "myvalue")
   expect_true(cookie$secure)
@@ -74,13 +56,15 @@ test_that("Parsing cookies works", {
   expect_equal(cookie$path, "/")
 
   # Value-less cookie
-  cookie <- parseCookie(parsedUrl, "mycookie=; Path = /")
+  cookie <- parseCookie("mycookie=; Path = /")
   expect_equal(cookie$name, "mycookie")
   expect_equal(cookie$value, "")
   expect_equal(cookie$path, "/")
 
   # prove #229 is fixed
-  cookie <- parseCookie(parsedUrl, "my_cookie-which/uses%20strange?characters=foo_-%20+?1234bar; Path = /")
+  cookie <- parseCookie(
+    "my_cookie-which/uses%20strange?characters=foo_-%20+?1234bar; Path = /"
+  )
   expect_equal(cookie$name, "my_cookie-which/uses%20strange?characters")
   expect_equal(cookie$value, "foo_-%20+?1234bar")
   expect_equal(cookie$path, "/")
@@ -88,36 +72,33 @@ test_that("Parsing cookies works", {
 
 test_that("Invalid cookies fail parsing", {
   # Invalid path, doesn't match request's path
-  parsedUrl <- parseHttpUrl("http://rstudio.com/test/stuff")
-  expect_warning({cookie <- parseCookie(parsedUrl, "mycookie=myvalue; Path=/something/else")},
-                 "Invalid path set for cookie")
+  expect_snapshot(cookie <- parseCookie("x=1; Path=/something/else", "/path"))
   expect_null(cookie)
 
   # Invalid key/val format
-  expect_warning({cookie <- parseCookie(parsedUrl, "mycookie;")},
-                 "Unable to parse set-cookie ")
+  expect_snapshot(cookie <- parseCookie("mycookie;"))
   expect_null(cookie)
 })
 
-clearCookieStore <- function() {
-  if (exists("fakedomain:123", .cookieStore)) {
-    rm("fakedomain:123", envir = .cookieStore)
-  }
-}
-
 test_that("cookies can be stored", {
-  clearCookieStore()
+  local_cookie_store()
 
   parsedUrl <- parseHttpUrl("http://fakedomain:123/test/stuff")
-  expect_warning({
-    storeCookies(parsedUrl, c(
-      "mycookie=myvalue; Path=/; Max-Age=3600; HttpOnly",
-      "anotherCookie=what; Path=/test; Max-Age=100",
-      "wrongpath=huh; Path=/uhoh; Max-Age=100",
-      "secureCookie=123; Secure",
-      "third=cookie; Path=/; Max-Age=500")
-    )
-  }, "Invalid path set for cookie")
+  expect_warning(
+    {
+      storeCookies(
+        parsedUrl,
+        c(
+          "mycookie=myvalue; Path=/; Max-Age=3600; HttpOnly",
+          "anotherCookie=what; Path=/test; Max-Age=100",
+          "wrongpath=huh; Path=/uhoh; Max-Age=100",
+          "secureCookie=123; Secure",
+          "third=cookie; Path=/; Max-Age=500"
+        )
+      )
+    },
+    "Invalid path set for cookie"
+  )
   cookies <- get("fakedomain:123", envir = .cookieStore)
   expect_equal(nrow(cookies), 4)
 
@@ -156,7 +137,7 @@ test_that("cookies can be stored", {
 })
 
 test_that("duplicate cookies overwrite one another", {
-  clearCookieStore()
+  local_cookie_store()
 
   parsedUrl <- parseHttpUrl("http://fakedomain:123/test/stuff")
   storeCookies(parsedUrl, "mycookie=myvalue; Path=/; Max-Age=3600")
@@ -180,35 +161,38 @@ test_that("duplicate cookies overwrite one another", {
 })
 
 test_that("appending cookie headers works", {
-  clearCookieStore()
+  local_cookie_store()
 
   parsedUrl <- parseHttpUrl("http://fakedomain:123/test/stuff")
 
   # Nothing to append, no-op
   headers <- appendCookieHeaders(parsedUrl, c(header1 = 123, header2 = "abc"))
   expect_length(headers, 2)
-  expect_equivalent(headers["header1"], "123")
-  expect_equivalent(headers["header2"], "abc")
+  expect_equal(headers[["header1"]], "123")
+  expect_equal(headers[["header2"]], "abc")
 
   # Store a cookie
   storeCookies(parsedUrl, "cookie1=value1; Path=/; Max-Age=3600")
 
   headers <- appendCookieHeaders(parsedUrl, c(header1 = 123, header2 = "abc"))
   expect_length(headers, 3)
-  expect_equivalent(headers["header1"], "123")
-  expect_equivalent(headers["header2"], "abc")
-  expect_equivalent(headers["cookie"], "cookie1=value1")
+  expect_equal(headers[["header1"]], "123")
+  expect_equal(headers[["header2"]], "abc")
+  expect_equal(headers[["cookie"]], "cookie1=value1")
 
   # Store a couple more cookies
   storeCookies(parsedUrl, "cookie2=value2; Path=/test; Max-Age=3600")
   # This one has the wrong path, will be filtered out
-  storeCookies(parseHttpUrl("http://fakedomain:123/another"), "cookie3=value3; Path=/another; Max-Age=3600")
+  storeCookies(
+    parseHttpUrl("http://fakedomain:123/another"),
+    "cookie3=value3; Path=/another; Max-Age=3600"
+  )
 
   headers <- appendCookieHeaders(parsedUrl, c(header1 = 123, header2 = "abc"))
   expect_length(headers, 3)
-  expect_equivalent(headers["header1"], "123")
-  expect_equivalent(headers["header2"], "abc")
-  expect_equivalent(headers["cookie"], "cookie2=value2; cookie1=value1")
+  expect_equal(headers[["header1"]], "123")
+  expect_equal(headers[["header2"]], "abc")
+  expect_equal(headers[["cookie"]], "cookie2=value2; cookie1=value1")
 
   # If you already have a cookie header, you end up with two
   headers <- appendCookieHeaders(parsedUrl, c(cookie = "existing=value"))
@@ -217,17 +201,26 @@ test_that("appending cookie headers works", {
   expect_equal(headers[2], c(cookie = "cookie2=value2; cookie1=value1"))
 
   # Add a secure cookie
-  storeCookies(parsedUrl, "securecookie=secureval; Path=/; Max-Age=3600; Secure")
+  storeCookies(
+    parsedUrl,
+    "securecookie=secureval; Path=/; Max-Age=3600; Secure"
+  )
   headers <- appendCookieHeaders(parsedUrl, c())
-  expect_equivalent(headers["cookie"], "cookie2=value2; cookie1=value1")
+  expect_equal(headers[["cookie"]], "cookie2=value2; cookie1=value1")
 
   # But over a secure channel, you'd include the secure cookie
-  headers <- appendCookieHeaders(parseHttpUrl("https://fakedomain:123/test/stuff"), c())
-  expect_equivalent(headers["cookie"], "securecookie=secureval; cookie2=value2; cookie1=value1")
+  headers <- appendCookieHeaders(
+    parseHttpUrl("https://fakedomain:123/test/stuff"),
+    c()
+  )
+  expect_equal(
+    headers[["cookie"]],
+    "securecookie=secureval; cookie2=value2; cookie1=value1"
+  )
 })
 
 test_that("Expired cookies are removed", {
-  clearCookieStore()
+  local_cookie_store()
 
   parsedUrl <- parseHttpUrl("http://fakedomain:123/test/stuff")
 
@@ -261,13 +254,19 @@ test_that("Expired cookies are removed", {
 
 test_that("getCookieHost works", {
   expect_equal(getCookieHost(parseHttpUrl("http://rstudio.com")), "rstudio.com")
-  expect_equal(getCookieHost(parseHttpUrl("http://rstudio.com:3939")), "rstudio.com:3939")
+  expect_equal(
+    getCookieHost(parseHttpUrl("http://rstudio.com:3939")),
+    "rstudio.com:3939"
+  )
   expect_equal(getCookieHost(parseHttpUrl("http://127.0.0.1")), "127.0.0.1")
-  expect_equal(getCookieHost(parseHttpUrl("http://127.0.0.1:3939")), "127.0.0.1:3939")
+  expect_equal(
+    getCookieHost(parseHttpUrl("http://127.0.0.1:3939")),
+    "127.0.0.1:3939"
+  )
 })
 
 test_that("getting and clearing cookies works", {
-  clearCookieStore()
+  local_cookie_store()
 
   all <- getCookies()
   expect_null(all)
@@ -310,5 +309,4 @@ test_that("getting and clearing cookies works", {
 
   all <- getCookies()
   expect_null(all)
-
 })
